<?xml version="1.0" encoding="UTF-8"?>
<tagger name="italian">

<tagset>
<!--  <def-label name="QUECNJ" closed="true">
    <tags-item lemma="che" tags="cnjsub"/>
  </def-label>
  <def-label name="QUEREL" closed="true">
    <tags-item lemma="che" tags="rel.*"/>
  </def-label>
  <def-label name="QUEPRN" closed="true">
    <tags-item lemma="che" tags="prn.itg.*"/>
  </def-label>-->
  <def-label name="ACRONIMOM">
    <tags-item tags="n.acr.m.*"/>
  </def-label>
  <def-label name="ACRONIMOF">
    <tags-item tags="n.acr.f.*"/>
  </def-label>
  <def-label name="ACRONIMOMF">
    <tags-item tags="n.acr.mf.*"/>
  </def-label>
  <def-label name="NOMM">
    <tags-item tags="n.m.*"/>
  </def-label>
  <def-label name="NOMF">
    <tags-item tags="n.f.*"/>
  </def-label>
  <def-label name="NOMMF">
    <tags-item tags="n.mf.*"/>
  </def-label>
  <def-label name="INTPRN" closed="true">
    <tags-item tags="prn.itg.*"/>
  </def-label> 
  <def-label name="INTADV" closed="true">
    <tags-item tags="adv.itg"/>
  </def-label>
  <def-label name="PREADV" closed="true">
    <tags-item tags="preadv"/>
  </def-label>
  <def-label name="ADV">
    <tags-item tags="adv"/>
  </def-label>
  <def-label name="CNJSUBS" closed="true">
    <tags-item tags="cnjsub"/>
  </def-label>
  <def-label name="CNJCOORD" closed="true">
    <tags-item tags="cnjcoo"/>
  </def-label>
  <def-label name="CNJADV">
    <tags-item tags="cnjadv"/>
  </def-label>
  <def-label name="DETNT" closed="true">
    <tags-item tags="detnt"/>
  </def-label>
<!--  <def-label name="DET" closed="true">
    <tags-item tags="det.*"/>
  </def-label> -->
 <def-label name="DETM" closed="true">
    <tags-item tags="det.*.m.*"/>
  </def-label>
  <def-label name="DETF" closed="true">
    <tags-item tags="det.*.f.*"/>
  </def-label>
  <def-label name="DETMF" closed="true">
    <tags-item tags="det.*.mf.*"/>
  </def-label>
  <def-label name="INTERJ">
    <tags-item tags="ij"/>
  </def-label> 
  <def-label name="ABBR">
    <tags-item tags="abbr"/>
  </def-label> 
  <def-label name="WEB">
    <tags-item tags="web"/>
  </def-label> 
  <def-label name="ANTROPONIM">
    <tags-item tags="np.ant.*"/>
    <tags-item tags="np.cog.*"/>
  </def-label>
  <def-label name="TOPONIM">
    <tags-item tags="np.top.*"/>
    <tags-item tags="np.loc.*"/>
    <tags-item tags="np.hyd.*"/>
  </def-label>
  <def-label name="NPALTRES">
    <tags-item tags="np.org.*"/>
    <tags-item tags="np.al"/>
    <tags-item tags="np.al.*"/>
  </def-label>
  <def-label name="NUM" closed="true">
    <tags-item tags="num.*"/>
    <tags-item tags="num"/>
    <tags-item tags="time"/>
  </def-label>
  <def-label name="PREDETNT" closed="true">
    <tags-item tags="predet.nt.*"/>
  </def-label> 
  <def-label name="PREDET" closed="true">
    <tags-item tags="predet.*"/>
  </def-label>
  <def-label name="PREP" closed="true">
    <tags-item tags="pr"/>
  </def-label>
  <def-label name="DAPREP" closed="true">
    <tags-item lemma="da" tags="pr"/>
  </def-label>
  <def-label name="PRNTNNT" closed="true">
    <tags-item tags="prn.tn.nt.*"/>
  </def-label>
  <def-label name="PRNTN" closed="true">
    <tags-item tags="prn.tn.*"/>
  </def-label>
  <def-label name="PRNENCREF" closed="true">
    <tags-item tags="prn.enc.ref.*"/>
  </def-label>
  <def-label name="PRNPROREF" closed="true">
    <tags-item tags="prn.pro.ref.*"/>
  </def-label>
  <def-label name="PRNENC" closed="true">
    <tags-item tags="prn.enc.*"/>
  </def-label>
  <def-label name="PRNPRO" closed="true">
    <tags-item tags="prn.pro.*"/>
  </def-label>
  <def-label name="VLEXINF">
    <tags-item tags="vblex.inf"/>
  </def-label>
  <def-label name="VLEXGER">
    <tags-item tags="vblex.ger"/>
  </def-label>
  <def-label name="VLEXPARTPI_SG">
    <tags-item tags="vblex.pp.*.sg"/>
    <tags-item tags="vblex.pprs.*.sg"/>
  </def-label>
  <def-label name="VLEXPARTPI_PL">
    <tags-item tags="vblex.pp.*.pl"/>
    <tags-item tags="vblex.pprs.*.pl"/>
  </def-label>
  <def-label name="VLEXPFCI">
    <tags-item tags="vblex.pri.*"/>
    <tags-item tags="vblex.fti.*"/>
    <tags-item tags="vblex.cni.*"/>
  </def-label>
  <def-label name="VLEXIPI">
    <tags-item tags="vblex.pii.*"/>
    <tags-item tags="vblex.ifi.*"/>
  </def-label>
  <def-label name="VLEXSUBJ">
    <tags-item tags="vblex.prs.*"/>
    <tags-item tags="vblex.pis.*"/>
    <tags-item tags="vblex.fts.*"/>
  </def-label>
  <def-label name="VLEXIMP">
    <tags-item tags="vblex.imp.*"/>
  </def-label>
  <def-label name="VSERINF" closed="true">
    <tags-item tags="vbser.inf"/>
  </def-label>
  <def-label name="VSERGER" closed="true">
    <tags-item tags="vbser.ger"/>
  </def-label>
  <def-label name="VSERPARTPI" closed="true">
    <tags-item tags="vbser.pp.*"/>
    <tags-item tags="vbser.pprs.*"/>
  </def-label>
  <def-label name="VSERPFCI_SG" closed="true">
    <tags-item tags="vbser.pri.*.sg"/>
    <tags-item tags="vbser.fti.*.sg"/>
    <tags-item tags="vbser.cni.*.sg"/>
  </def-label>
  <def-label name="VSERPFCI_PL" closed="true">
    <tags-item tags="vbser.pri.*.pl"/>
    <tags-item tags="vbser.fti.*.pl"/>
    <tags-item tags="vbser.cni.*.pl"/>
  </def-label>
  <def-label name="VSERIPI" closed="true">
    <tags-item tags="vbser.pii.*"/>
    <tags-item tags="vbser.ifi.*"/>
  </def-label>
  <def-label name="VSERSUBJ" closed="true">
    <tags-item tags="vbser.prs.*"/>
    <tags-item tags="vbser.pis.*"/>
    <tags-item tags="vbser.fts.*"/>
  </def-label>
  <def-label name="VSERIMP" closed="true">
    <tags-item tags="vbser.imp.*"/>
  </def-label>

  <def-label name="AVEREINF" closed="true">
    <tags-item tags="vbhaver.inf"/>
  </def-label>
  <def-label name="AVEREGER" closed="true">
    <tags-item tags="vbhaver.ger"/>
  </def-label>
  <def-label name="AVEREPARTPI" closed="true">
    <tags-item tags="vbhaver.pp.*"/>
    <tags-item tags="vbhaver.pprs.*"/>
  </def-label>
  <def-label name="AVEREPFCI" closed="true">
    <tags-item tags="vbhaver.pri.*"/>
    <tags-item tags="vbhaver.fti.*"/>
    <tags-item tags="vbhaver.cni.*"/>
  </def-label>
  <def-label name="AVEREIMP" closed="true">
    <tags-item tags="vbhaver.imp.*"/>
  </def-label>
  <def-label name="AVEREIPI" closed="true">
    <tags-item tags="vbhaver.pii.*"/>
    <tags-item tags="vbhaver.ifi.*"/>
  </def-label>
  <def-label name="AVERESUBJ" closed="true">
    <tags-item tags="vbhaver.prs.*"/>
    <tags-item tags="vbhaver.pis.*"/>
    <tags-item tags="vbhaver.fts.*"/>
  </def-label>
  <def-label name="VMODALINF" closed="true">
    <tags-item tags="vbmod.inf"/>
  </def-label>
  <def-label name="VMODALGER" closed="true">
    <tags-item tags="vbmod.ger"/>
  </def-label>
  <def-label name="VMODALPARTPI" closed="true">
    <tags-item tags="vbmod.pp.*"/>
    <tags-item tags="vbmod.pprs.*"/>
  </def-label>
  <def-label name="VMODALPFCI" closed="true">
    <tags-item tags="vbmod.pri.*"/>
    <tags-item tags="vbmod.fti.*"/>
    <tags-item tags="vbmod.cni.*"/>
  </def-label>
  <def-label name="VMODALIPI" closed="true">
    <tags-item tags="vbmod.pii.*"/>
    <tags-item tags="vbmod.ifi.*"/>
  </def-label>
  <def-label name="VMODALSUBJ" closed="true">
    <tags-item tags="vbmod.prs.*"/>
    <tags-item tags="vbmod.pis.*"/>
    <tags-item tags="vbmod.fts.*"/>
  </def-label>
  <def-label name="VMODALIMP" closed="true">
    <tags-item tags="vbmod.imp.*"/>
  </def-label> 
 <def-label name="ADJF">
   <tags-item tags="adj.f.*"/>
   <tags-item tags="adj.ind.f.*"/>
   <tags-item tags="adj.ind.sup.f.*"/>
   <tags-item tags="adj.ord.f.*"/>
   <tags-item tags="adj.sup.f.*"/>
 </def-label>
 <def-label name="ADJM">
   <tags-item tags="adj.m.*"/>
   <tags-item tags="adj.ind.m.*"/>
   <tags-item tags="adj.ind.sup.m.*"/>
   <tags-item tags="adj.ord.m.*"/>
   <tags-item tags="adj.sup.m.*"/>
 </def-label>
 <def-label name="ADJMF">
   <tags-item tags="adj.mf.*"/>
   <tags-item tags="adj.ind.mf.*"/>
   <tags-item tags="adj.ind.sup.mf.*"/>
   <tags-item tags="adj.ord.mf.*"/>
   <tags-item tags="adj.sup.mf.*"/>
 </def-label> 
 <def-label name="ADJINT" closed="true">
    <tags-item tags="adj.itg.*"/>
  </def-label>
 <def-label name="ADJPOS" closed="true">
    <tags-item tags="adj.pos.*"/>
  </def-label>
  <def-label name="RELN" closed="true">
    <tags-item tags="rel.an.*"/>
    <tags-item tags="rel.nn.*"/>
  </def-label>
  <def-label name="RELAA" closed="true">
    <tags-item tags="rel.aa.*"/>
  </def-label>
  <def-label name="RELADV" closed="true">
    <tags-item tags="rel.adv"/>
  </def-label>
  <def-label name="APOS" closed="true">
    <tags-item tags="apos"/>
  </def-label>

  <def-label name="TIME" closed="true">
    <tags-item tags="time"/>
  </def-label>

  <def-mult name="PREPDET" closed="true">
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.def.m.sg"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.def.m.pl"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.def.f.sg"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.def.f.pl"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.pos.m.sg"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.pos.m.pl"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.pos.f.sg"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.pos.f.pl"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.mf.sg"/>
    </sequence>

 <sequence>
      <label-item label="DAPREP"/>
      <tags-item tags="det.def.m.sg"/>
    </sequence>
    <sequence>
      <label-item label="DAPREP"/>
      <tags-item tags="det.def.m.pl"/>
    </sequence>
    <sequence>
      <label-item label="DAPREP"/>
      <tags-item tags="det.def.f.sg"/>
    </sequence>
    <sequence>
      <label-item label="DAPREP"/>
      <tags-item tags="det.def.f.pl"/>
    </sequence>
    <sequence>
      <label-item label="DAPREP"/>
      <tags-item tags="det.pos.m.sg"/>
    </sequence>
    <sequence>
      <label-item label="DAPREP"/>
      <tags-item tags="det.pos.m.pl"/>
    </sequence>
    <sequence>
      <label-item label="DAPREP"/>
      <tags-item tags="det.pos.f.sg"/>
    </sequence>
    <sequence>
      <label-item label="DAPREP"/>
      <tags-item tags="det.pos.f.pl"/>
    </sequence>
    <sequence>
      <label-item label="DAPREP"/>
      <tags-item tags="det.mf.sg"/>
    </sequence>


  </def-mult>

  <def-mult name="PREPPRN" closed="true">
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="prn.tn.pos.m.sg"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="prn.tn.pos.m.pl"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="prn.tn.pos.f.sg"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="prn.tn.pos.f.pl"/>
    </sequence>
  </def-mult>
<!--
  <def-mult name="PRCNJ" closed="true">
    <sequence>
      <label-item label="PREP"/>
      <label-item label="QUECNJ"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <label-item label="CNJSUBS"/>
    </sequence>
  </def-mult>
  <def-mult name="PRREL" closed="true">
    <sequence>
      <label-item label="PREP"/>
      <label-item label="QUEREL"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <label-item label="RELN"/>
    </sequence>
  </def-mult> 
-->
  <def-mult name="INFLEXPRNENC">
    <sequence>
      <label-item label="VLEXINF"/>
      <label-item label="PRNENC"/>
   </sequence>
    <sequence>
      <label-item label="VLEXINF"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
   </sequence>
  </def-mult>
  <def-mult name="GERLEXPRNENC">
    <sequence>
      <label-item label="VLEXGER"/>
      <label-item label="PRNENC"/>
   </sequence>
    <sequence>
      <label-item label="VLEXGER"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
   </sequence>
  </def-mult>
  <def-mult name="IMPLEXPRNENC">
    <sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="PRNENC"/>
   </sequence>
    <sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
   </sequence>
  </def-mult>
  <def-mult name="INFSERPRNENC" closed="true">
    <sequence>
      <label-item label="VSERINF"/>
      <label-item label="PRNENC"/>
    </sequence>
    <sequence>
      <label-item label="VSERINF"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
  <def-mult name="GERSERPRNENC" closed="true">
    <sequence>
      <label-item label="VSERGER"/>
      <label-item label="PRNENC"/>
    </sequence>
    <sequence>
      <label-item label="VSERGER"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
  <def-mult name="IMPSERPRNENC" closed="true">
    <sequence>
      <label-item label="VSERIMP"/>
      <label-item label="PRNENC"/>
    </sequence>
    <sequence>
      <label-item label="VSERIMP"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
  <def-mult name="INFHABERPRNENC" closed="true">
    <sequence>
      <label-item label="AVEREINF"/>
      <label-item label="PRNENC"/>
    </sequence>
    <sequence>
      <label-item label="AVEREINF"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
  <def-mult name="GERHABERPRNENC" closed="true">
    <sequence>
      <label-item label="AVEREGER"/>
      <label-item label="PRNENC"/>
    </sequence>
    <sequence>
      <label-item label="AVEREGER"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
  <def-mult name="INFMODPRNENC" closed="true">
    <sequence>
      <label-item label="VMODALINF"/>
      <label-item label="PRNENC"/>
    </sequence>
    <sequence>
      <label-item label="VMODALINF"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
  <def-mult name="GERMODPRNENC" closed="true">
    <sequence>
      <label-item label="VMODALGER"/>
      <label-item label="PRNENC"/>
    </sequence>
    <sequence>
      <label-item label="VMODALGER"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
  <def-mult name="IMPMODPRNENC" closed="true">
    <sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="PRNENC"/>
    </sequence>
    <sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="PRNENC"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
  <def-mult name="PROPRO" closed="true">
    <sequence>
      <label-item label="PRNPRO"/>
      <label-item label="PRNPRO"/>
    </sequence>
  </def-mult>
</tagset>

  <forbid>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="PREP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="PREPDET"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="PREPPRN"/>
    </label-sequence>


    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERPFCI_SG"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERPFCI_PL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="AVEREPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="AVEREIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="AVERESUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>


    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERPFCI_SG"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERPFCI_PL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="AVEREPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="AVEREIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="AVERESUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="AVEREGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERPFCI_SG"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERPFCI_PL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="AVEREPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="AVEREIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="AVERESUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="AVEREGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
   <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERPFCI_SG"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERPFCI_PL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="AVEREPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="AVEREIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="AVERESUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="AVEREGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="VLEXGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="VLEXINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="VSERINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="AVEREGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="AVEREINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="VMODALINF"/>
    </label-sequence>
 

    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VLEXGER"/>
    </label-sequence>



    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VSERPFCI_SG"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VSERPFCI_PL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VSERGER"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VSERPARTPI"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VSERPARTPI"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="AVEREPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="AVEREPDET"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="AVERESUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="AVEREIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="AVEREGER"/>
    </label-sequence>


    <label-sequence>
      <label-item label="PREPPRN"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPPRN"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPPRN"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPPRN"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="VLEXGER"/>
    </label-sequence>



    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETNT"/>
      <label-item label="NUM"/>
    </label-sequence>


    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="PRNPRO"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="PRNENC"/>
    </label-sequence>


    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="PRNPRO"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="PRNENC"/>
    </label-sequence>

    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="PRNPRO"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="PRNENC"/>
    </label-sequence>

    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="DETMF"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VSERPFCI_SG"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VSERPFCI_PL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="AVEREPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="AVEREIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="AVERESUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VSERPFCI_SG"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VSERPFCI_PL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="AVEREPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="AVEREIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="AVERESUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VSERPFCI_SG"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VSERPFCI_PL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="AVEREPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="AVEREIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="AVERESUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>


    <label-sequence>
      <label-item label="PREADV"/>
      <label-item label="SENT"/>
    </label-sequence>

    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="SENT"/>
    </label-sequence>   
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREDET"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREDETNT"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="RELN"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="RELAA"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="RELADV"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="CNJCOORD"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="CNJSUBS"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="CNJADV"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="SENT"/>
    </label-sequence>

    <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOM"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOM"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOM"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOF"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOF"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOF"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOMF"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOMF"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOMF"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOM"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOM"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOM"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOF"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOF"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOF"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOMF"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOMF"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ACRONIMOMF"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>

    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>


    <label-sequence>
      <label-item label="CNJADV"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="CNJSUBS"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VSERPFCI_SG"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VSERPFCI_PL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="AVEREPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="AVEREIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="AVERESUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>  

<!--
    <label-sequence>
      <label-item label="VLEXINF"/>
      <label-item label="PRREL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXGER"/>
      <label-item label="PRREL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="PRREL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="PRREL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXPFCI"/>
      <label-item label="PRREL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIPI"/>
      <label-item label="PRREL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXSUBJ"/>
      <label-item label="PRREL"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="PRREL"/>
    </label-sequence> 
-->

    <label-sequence>
      <label-item label="VMODALINF"/><!--Afegit 17/01/2006 fins a VMODALIMP-->
      <label-item label="DETNT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="NOMMF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="ADJM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALINF"/>
      <label-item label="ADJPOS"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="DETNT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="NOMMF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="ADJM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALGER"/>
      <label-item label="ADJPOS"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="DETNT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="NOMMF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="ADJM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPARTPI"/>
      <label-item label="ADJPOS"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="DETNT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="NOMMF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="ADJM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="ADJPOS"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="DETNT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="NOMMF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="ADJM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="ADJPOS"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="DETNT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="NOMMF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="ADJM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="ADJPOS"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="DETNT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="NOMMF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="ADJM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="ADJPOS"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VSERPFCI_PL"/>
      <label-item label="VLEXPARTPI_SG"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VSERPFCI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VSERPFCI_PL"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VSERPFCI_SG"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VSERPFCI_PL"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VSERPFCI_SG"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>


    <label-sequence>
      <label-item label="VSERIPI"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VSERSUBJ"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>

    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="DETNT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="DETMF"/>
    </label-sequence>

    <label-sequence>
      <label-item label="DETPRN"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETPRN"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETPRN"/>
      <label-item label="NOMMF"/>
    </label-sequence>


    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="PREPDET"/>
    </label-sequence>
    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="PREPPRN"/>
    </label-sequence>

    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="AVEREIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="INTPRN"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>


    <label-sequence>
      <label-item label="PRNTNNT"/>
      <label-item label="ADJF"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PRNTNNT"/>
      <label-item label="ADJM"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PRNTNNT"/>
      <label-item label="ADJMF"/>
    </label-sequence>


    <label-sequence>
      <label-item label="PRNTN"/>
      <label-item label="NOMF"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PRNTN"/>
      <label-item label="NOMM"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PRNTN"/>
      <label-item label="NOMMF"/>
    </label-sequence>




    <label-sequence>
      <label-item label="PREPPRN"/>
      <label-item label="NOMF"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PREPPRN"/>
      <label-item label="NOMM"/>
    </label-sequence>

    <label-sequence>
      <label-item label="PREPPRN"/>
      <label-item label="NOMMF"/>
    </label-sequence>

    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="INTPRN"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="INTPRN"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="INTPRN"/>
    </label-sequence>   


  </forbid>


  <enforce-rules>
    <enforce-after label="PRNPRO">
      <label-set>
        <label-item label="PRNPRO"/>
        <label-item label="VLEXPFCI"/>
        <label-item label="VLEXIPI"/>
        <label-item label="VLEXSUBJ"/>
        <label-item label="VSERPFCI_SG"/>
        <label-item label="VSERPFCI_PL"/>
        <label-item label="VSERIPI"/>
        <label-item label="VSERSUBJ"/>
        <label-item label="AVEREPFCI"/>
        <label-item label="AVEREIPI"/>
        <label-item label="AVERESUBJ"/>
        <label-item label="VMODALPFCI"/>
        <label-item label="VMODALIPI"/>
        <label-item label="VMODALSUBJ"/>
      </label-set>
    </enforce-after>


    <enforce-after label="AVEREINF">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="AVEREPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>

    <enforce-after label="AVEREGER">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="AVEREPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>
    <enforce-after label="AVEREPARTPI">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="AVEREPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>

    <enforce-after label="AVEREPFCI">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="AVEREPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>
    <enforce-after label="AVEREIMP">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="AVEREPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>
    <enforce-after label="AVEREIPI">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="AVEREPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>
    <enforce-after label="AVERESUBJ">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="AVEREPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>





    <enforce-after label="VSERINF">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>

    <enforce-after label="VSERGER">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>
    <enforce-after label="VSERPARTPI">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>

    <enforce-after label="VSERPFCI">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI"/>
      <label-item label="VSERPARTPI_PL"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>
    <enforce-after label="VSERIMP">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>
    <enforce-after label="VSERIPI">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>
    <enforce-after label="VSERSUBJ">
      <label-set>
      <label-item label="VLEXPARTPI_SG"/>
      <label-item label="VLEXPARTPI_PL"/>
      <label-item label="VSERPARTPI"/>
      <label-item label="VMODALPARTPI"/>
      <label-item label="PRNENCREF"/>
      <label-item label="PRNENC"/>
      </label-set>
    </enforce-after>




  </enforce-rules>

  <preferences>
   <prefer tags="vbmod.pri.p3.sg"/>
   <prefer tags="vbhaver.pri.p3.sg"/>
   <prefer tags="vblex.pri.p3.sg"/>
   <prefer tags="vbser.pri.p3.sg"/>

   <prefer tags="vblex.pii.p3.sg"/>
   <prefer tags="vbser.pii.p3.sg"/>
   <prefer tags="vbhaver.pii.p3.sg"/>
   <prefer tags="vbmod.pii.p3.sg"/>

   <prefer tags="vblex.prs.p3.sg"/>
   <prefer tags="vbser.prs.p3.sg"/>
   <prefer tags="vbhaver.prs.p3.sg"/>
   <prefer tags="vbmod.prs.p3.sg"/>
   <prefer tags="vblex.cni.p3.sg"/>
   <prefer tags="vbser.cni.p3.sg"/>
   <prefer tags="vbhaver.cni.p3.sg"/>
   <prefer tags="vbmod.cni.p3.sg"/>
   <prefer tags="vblex.pis.p3.sg"/>
   <prefer tags="vbser.pis.p3.sg"/>
   <prefer tags="vbhaver.pis.p3.sg"/>
   <prefer tags="vbmod.pis.p3.sg"/>

   <prefer tags="rel.an.mf.sp"/>
   <prefer tags="cnjsub"/>
   <prefer tags="rel.adv"/>
   <prefer tags="det.def.m.sg"/>
   <prefer tags="det.def.f.sg"/>
   <prefer tags="det.def.m.pl"/>
   <prefer tags="det.def.f.pl"/>

   <prefer tags="det.dem.m.sg"/>
   <prefer tags="det.dem.f.sg"/>
   <prefer tags="det.dem.m.pl"/>
   <prefer tags="det.dem.f.pl"/>





  </preferences>
</tagger>
